# Generated by Django 3.2.3 on 2021-10-03 15:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('custom_menu', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='custommenu',
            name='name',
            field=models.CharField(choices=[('top', 'Horní menu'), ('footer', 'Patička')], max_length=50),
        ),
    ]
