# Generated by Django 3.2.3 on 2021-10-03 15:55

from django.db import migrations
import wagtail.blocks
import wagtail.fields


class Migration(migrations.Migration):

    dependencies = [
        ('custom_menu', '0003_auto_20211003_1538'),
    ]

    operations = [
        migrations.AddField(
            model_name='custommenu',
            name='content',
            field=wagtail.fields.StreamField([('linkblock', wagtail.blocks.StructBlock([], stream_blocks=[('name', wagtail.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True))]))], default=[]),
        ),
    ]
