# Generated by Django 3.1.8 on 2021-05-11 16:25

from django.db import migrations
import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('streamfield', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='gallery',
            name='stream',
            field=wagtail.fields.StreamField([('gallery_image', wagtail.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock())], icon='image', label='Image'))], default=None),
            preserve_default=False,
        ),
    ]
