# Generated by Django 3.2.13 on 2022-06-07 15:06

from django.db import migrations
import wagtail.blocks
import wagtail.fields


class Migration(migrations.Migration):

    dependencies = [
        ('custom_menu', '0008_alter_custommenu_stream'),
    ]

    operations = [
        migrations.AlterField(
            model_name='custommenu',
            name='stream',
            field=wagtail.fields.StreamField([('containers', wagtail.blocks.StructBlock([('stream', wagtail.blocks.StreamBlock([('container', wagtail.blocks.StructBlock([('stream', wagtail.blocks.StreamBlock([('nestedlinkblock', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True)), ('page', wagtail.blocks.PageChooserBlock(label='A page to be opened')), ('icon', wagtail.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka'), ('people', 'Lidi'), ('info', 'Informace'), ('hand', 'Ruka'), ('child', 'Dítě'), ('label', 'Popisek')], label='The icon'))])), ('linkcategory', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Name of the category', max_length=50, required=True)), ('stream', wagtail.blocks.StreamBlock([('nestedlinkblock', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True)), ('page', wagtail.blocks.PageChooserBlock(label='A page to be opened')), ('icon', wagtail.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka'), ('people', 'Lidi'), ('info', 'Informace'), ('hand', 'Ruka'), ('child', 'Dítě'), ('label', 'Popisek')], label='The icon'))])), ('categorychildren', wagtail.blocks.StructBlock([('parent', wagtail.blocks.PageChooserBlock(label='A page which children should be listed'))]))], label='A nested content of a category')), ('icon', wagtail.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka'), ('people', 'Lidi'), ('info', 'Informace'), ('hand', 'Ruka'), ('child', 'Dítě'), ('label', 'Popisek')], label='The icon'))]))], empty=True, label='Content of Column'))], icon='doc-full', label='Sloupec'))], label='Columns'))], icon='container', label='Více sloupců')), ('linkblock', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True)), ('page', wagtail.blocks.PageChooserBlock(label='A page to be opened')), ('icon', wagtail.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka'), ('people', 'Lidi'), ('info', 'Informace'), ('hand', 'Ruka'), ('child', 'Dítě'), ('label', 'Popisek')], label='The icon'))])), ('linkcategory', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Name of the category', max_length=50, required=True)), ('stream', wagtail.blocks.StreamBlock([('nestedlinkblock', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True)), ('page', wagtail.blocks.PageChooserBlock(label='A page to be opened')), ('icon', wagtail.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka'), ('people', 'Lidi'), ('info', 'Informace'), ('hand', 'Ruka'), ('child', 'Dítě'), ('label', 'Popisek')], label='The icon'))])), ('categorychildren', wagtail.blocks.StructBlock([('parent', wagtail.blocks.PageChooserBlock(label='A page which children should be listed'))]))], label='A nested content of a category')), ('icon', wagtail.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka'), ('people', 'Lidi'), ('info', 'Informace'), ('hand', 'Ruka'), ('child', 'Dítě'), ('label', 'Popisek')], label='The icon'))]))], default=[]),
        ),
    ]
